import { AxiosInstance, AxiosResponse } from 'axios';
export declare class RecordsAPIClient {
    protected instance: AxiosInstance;
    protected baseUrl: string;
    protected jsonParseReviver: ((key: string, value: any) => any) | undefined;
    constructor(baseUrl: string, instance?: AxiosInstance);
    /**
     * @param body (optional)
     * @return Success
     */
    recordPost(body: Record | undefined, signal?: AbortSignal): Promise<Record>;
    protected processRecordPost(response: AxiosResponse): Promise<Record>;
    /**
     * @param body (optional)
     * @return Success
     */
    recordQueryByIndex(body: QueryByIndexRQ | undefined, signal?: AbortSignal): Promise<QueryByIndexRS>;
    protected processRecordQueryByIndex(response: AxiosResponse): Promise<QueryByIndexRS>;
    /**
     * @param body (optional)
     * @return Success
     */
    recordPatch(id: number, body: Record | undefined, signal?: AbortSignal): Promise<Record>;
    protected processRecordPatch(response: AxiosResponse): Promise<Record>;
    /**
     * @return Success
     */
    recordGet(id: number, signal?: AbortSignal): Promise<Record>;
    protected processRecordGet(response: AxiosResponse): Promise<Record>;
    /**
     * @return Success
     */
    recordDelete(id: number, signal?: AbortSignal): Promise<void>;
    protected processRecordDelete(response: AxiosResponse): Promise<void>;
    /**
     * @return Success
     */
    recordGetSingleByIdentifier(identifier: string, signal?: AbortSignal): Promise<Record>;
    protected processRecordGetSingleByIdentifier(response: AxiosResponse): Promise<Record>;
    /**
     * @param id (optional)
     * @param recordId (optional)
     * @param type (optional)
     * @return Success
     */
    recordAddRelationship(id: number | undefined, recordId: number | undefined, type: RelationshipTypes | undefined, signal?: AbortSignal): Promise<void>;
    protected processRecordAddRelationship(response: AxiosResponse): Promise<void>;
    /**
     * @param id (optional)
     * @param recordId (optional)
     * @return Success
     */
    recordRemoveRelationship(id: number | undefined, recordId: number | undefined, signal?: AbortSignal): Promise<void>;
    protected processRecordRemoveRelationship(response: AxiosResponse): Promise<void>;
    /**
     * @param body (optional)
     * @return Success
     */
    recordQueryPost(body: RecordQueryCreateRQ | undefined, signal?: AbortSignal): Promise<RecordQuery>;
    protected processRecordQueryPost(response: AxiosResponse): Promise<RecordQuery>;
    /**
     * @param body (optional)
     * @return Success
     */
    recordQueryExecute(body: ExecuteQueryRQ | undefined, signal?: AbortSignal): Promise<RecordQueryExecuteRS>;
    protected processRecordQueryExecute(response: AxiosResponse): Promise<RecordQueryExecuteRS>;
    /**
     * @param body (optional)
     * @return Success
     */
    recordQueryPatch(id: number, body: RecordQueryUpdateRQ | undefined, signal?: AbortSignal): Promise<RecordQuery>;
    protected processRecordQueryPatch(response: AxiosResponse): Promise<RecordQuery>;
    /**
     * @return Success
     */
    recordQueryGet(id: number, signal?: AbortSignal): Promise<RecordQuery>;
    protected processRecordQueryGet(response: AxiosResponse): Promise<RecordQuery>;
    /**
     * @return Success
     */
    recordQueryDelete(id: number, signal?: AbortSignal): Promise<void>;
    protected processRecordQueryDelete(response: AxiosResponse): Promise<void>;
    /**
     * @param body (optional)
     * @return Success
     */
    recordQueryExecuteById(body: RecordQueryExecuteRQ | undefined, signal?: AbortSignal): Promise<RecordQueryExecuteRS>;
    protected processRecordQueryExecuteById(response: AxiosResponse): Promise<RecordQueryExecuteRS>;
    /**
     * @param body (optional)
     * @return Success
     */
    recordTypePost(body: RecordTypeCreateRQ | undefined, signal?: AbortSignal): Promise<RecordType>;
    protected processRecordTypePost(response: AxiosResponse): Promise<RecordType>;
    /**
     * @param body (optional)
     * @return Success
     */
    recordTypePatch(id: number, body: RecordTypeUpdateRQ | undefined, signal?: AbortSignal): Promise<RecordType>;
    protected processRecordTypePatch(response: AxiosResponse): Promise<RecordType>;
    /**
     * @return Success
     */
    recordTypeGet(id: number, signal?: AbortSignal): Promise<RecordType>;
    protected processRecordTypeGet(response: AxiosResponse): Promise<RecordType>;
    /**
     * @return Success
     */
    recordTypeDelete(id: number, signal?: AbortSignal): Promise<void>;
    protected processRecordTypeDelete(response: AxiosResponse): Promise<void>;
}
export interface DBRecord {
    id?: number;
    active?: boolean;
    creationTime?: Date | undefined;
    lastUpdateTime?: Date | undefined;
    isDeleted?: boolean;
}
export interface BaseProfileRecord extends DBRecord {
    accountId?: number;
}
export interface Account extends BaseProfileRecord {
    name?: string | undefined;
    organizationId?: number;
    parentId?: number | undefined;
    contactInformation?: ContactInformation;
}
export interface Address {
    street?: string | undefined;
    number?: string | undefined;
    complement?: string | undefined;
    zipCode?: string | undefined;
    neighborhood?: string | undefined;
    city?: string | undefined;
    state?: string | undefined;
    countryCode?: string | undefined;
    longitude?: number | undefined;
    latitude?: number | undefined;
}
export declare enum AgeGroup {
    Adult = "Adult",
    Child = "Child",
    Infant = "Infant"
}
export interface AgreementDifference {
    adtPercentage?: number | undefined;
    adtAmount?: Money;
    adtPublicFare?: Money;
    chdPercentage?: number | undefined;
    chdAmount?: Money;
    chdPublicFare?: Money;
    infPercentage?: number | undefined;
    infAmount?: Money;
    infPublicFare?: Money;
}
export interface AirCommercialAgreement {
    code?: string | undefined;
    airCompanyCode?: string | undefined;
    type?: AirCommercialAgreementType;
    supplierSystemName?: string | undefined;
    travelerCodeOverride?: string | undefined;
}
export interface AirCommercialAgreementRecord extends BaseProfileRecord {
    name?: string | undefined;
    commercialAgreement?: AirCommercialAgreement;
    allowedBoardRanges?: DateTimeRange[] | undefined;
    allowedIssueRanges?: DateTimeRange[] | undefined;
    allowedOrigins?: number[] | undefined;
    allowedDestinations?: number[] | undefined;
    allowedTripType?: TripType;
}
export declare enum AirCommercialAgreementType {
    Contract = "Contract",
    Corporate = "Corporate",
    Account = "Account",
    TourCode = "TourCode",
    PTC = "PTC"
}
export interface AirCompany extends DBRecord {
    code?: string | undefined;
    name?: string | undefined;
    displayName?: string | undefined;
    showOnEngine?: boolean;
}
export interface Reservation {
    locator?: string | undefined;
    supplierSystem?: string | undefined;
    status?: ReservationStatus;
    createdWithEnvisionSystem?: boolean;
    supplierExpirationTime?: Date | undefined;
    expirationTime?: Date | undefined;
    supplierCredentialsIdentification?: string | undefined;
    travellers?: Traveller[] | undefined;
    bookTime?: Date;
    cancellationDeadlineTime?: Date | undefined;
    remarks?: Remark[] | undefined;
    penalty?: Money;
    balanceDue?: Money;
    totalValue?: Money;
    externalProperties?: {
        [key: string]: string;
    } | undefined;
    payments?: Payment[] | undefined;
    type?: ReservationType;
    flightGroups?: FlightGroup[] | undefined;
}
export interface AirReservation extends Reservation {
    flightGroups?: FlightGroup[] | undefined;
    bookingFares?: BookingFare[] | undefined;
    osIs?: OSI[] | undefined;
    ssRs?: SSR[] | undefined;
    frequentFlyers?: FrequentFlyer[] | undefined;
    tsAs?: TSA[] | undefined;
    seats?: AirReservationSeat[] | undefined;
    tickets?: AirTicket[] | undefined;
    ticketsPaymentsRelationships?: TicketsPaymentsRelationship[] | undefined;
    capabilities?: AirReservationCapabilities;
    refunds?: AirReservationRefund[] | undefined;
    credits?: AirReservationCredit[] | undefined;
    type?: ReservationType;
}
export interface AirReservationCapabilities {
    cancel?: boolean;
    issue?: boolean;
    split?: boolean;
    reassessFare?: boolean;
    alterFlightGroups?: boolean;
    addRemarks?: boolean;
    removeRemarks?: boolean;
    addSSRs?: boolean;
    removeSSRs?: boolean;
    addOSIs?: boolean;
    removeOSIs?: boolean;
    addTSAs?: boolean;
    removeTSAs?: boolean;
    addFrequentFlyers?: boolean;
    removeFrequentFlyers?: boolean;
    issueMode?: AirReservationIssueMode;
}
export interface AirReservationCredit {
    totalAmount?: Money;
    dateReleased?: Date;
}
export declare enum AirReservationIssueMode {
    ByTicket = "ByTicket",
    ByBalance = "ByBalance"
}
export interface Record extends DBRecord {
    readonly recordTypeName?: string | undefined;
    accountId?: number;
    parentId?: number;
    identifier?: string | undefined;
    relationships?: Relationship[] | undefined;
    [key: string]: any;
}
export interface AirReservationRecord extends Record {
    readonly recordTypeName?: string | undefined;
    tripAPIOrder?: TripAPIOrder;
    origin?: string | undefined;
    destination?: string | undefined;
    startDate?: Date | undefined;
    ciaNames?: string | undefined;
    [key: string]: any;
}
export interface AirReservationRefund {
    totalAmount?: Money;
    authorizationCode?: string | undefined;
    ticketNumber?: string | undefined;
    dateRefunded?: Date;
}
export interface AirReservationSeat {
    identification?: string | undefined;
    flightNumber?: string | undefined;
    travellerName?: string | undefined;
    originalValue?: Money;
    equivalentValue?: Money;
    externalProperties?: {
        [key: string]: string;
    } | undefined;
    status?: SeatStatus;
    credentialIdentifier?: string | undefined;
}
export interface AirSearchCachedResponse extends DBRecord {
    flightGroups?: FlightGroup[] | undefined;
}
export interface AirSeatRecord extends Record {
    readonly recordTypeName?: string | undefined;
    airReservationSeat?: AirReservationSeat;
    airReservation?: AirReservation;
    [key: string]: any;
}
export interface AirTicket {
    number?: string | undefined;
    status?: AirTicketStatus;
    externalProperties?: {
        [key: string]: string;
    } | undefined;
    issueTime?: Date;
    bookingFare?: BookingFare;
    travellerName?: string | undefined;
    comission?: string | undefined;
    endorsement?: string | undefined;
    tourCode?: string | undefined;
    ticketRefund?: AirTicketRefund;
    penalty?: Money;
    discount?: Money;
    pnrLocator?: string | undefined;
    supplierSystemName?: string | undefined;
    issuerAirCompanyCode?: string | undefined;
    flights?: Flight[] | undefined;
    credentialIdentifier?: string | undefined;
}
export interface AirTicketRecord extends Record {
    readonly recordTypeName?: string | undefined;
    airTicket?: AirTicket;
    airReservation?: AirReservation;
    origin?: string | undefined;
    destination?: string | undefined;
    startDate?: Date | undefined;
    ciaNames?: string | undefined;
    [key: string]: any;
}
export interface AirTicketRefund {
    penalty?: Money;
    totalRefunded?: Money;
    taxesAmount?: Money;
    fareAmount?: Money;
    duTaxes?: Money;
    authorizationCode?: string | undefined;
    message?: string | undefined;
}
export interface AirTicketReplacementInformation {
    ticketNumber?: string | undefined;
}
export declare enum AirTicketStatus {
    NotIssued = "NotIssued",
    Issued = "Issued",
    Pending = "Pending",
    WaitingForNumber = "WaitingForNumber",
    Cancelled = "Cancelled",
    Replaced = "Replaced",
    Refunded = "Refunded"
}
export interface Credential {
    readonly supplierSystemName?: string | undefined;
    travelAgencyContactInformation?: CompanyContactInformation;
    maxSessionPoolConnections?: number;
    isProductionEnvironment?: boolean;
    credentialPublicFare?: Credential;
}
export interface AmadeusCredential extends Credential {
    readonly supplierSystemName?: string | undefined;
    url?: string | undefined;
    userID?: string | undefined;
    password?: string | undefined;
    officeID?: string | undefined;
    wsap?: string | undefined;
    agentDutyCode?: string | undefined;
    marketIataCode?: string | undefined;
    excludeIssueAirCompanies?: string[] | undefined;
}
export interface FareLogixCredential extends Credential {
    agency?: string | undefined;
    agencyPassword?: string | undefined;
    iata?: string | undefined;
    pcc?: string | undefined;
    subscriptionKey?: string | undefined;
    url?: string | undefined;
    user?: string | undefined;
    userPassword?: string | undefined;
}
export interface AmericanAirlinesCredential extends FareLogixCredential {
    readonly supplierSystemName?: string | undefined;
}
export interface ApiKey extends BaseProfileRecord {
    externalId?: string | undefined;
    token?: string | undefined;
    name?: string | undefined;
    userId?: number;
}
export interface AviancaCredential extends Credential {
    readonly supplierSystemName?: string | undefined;
    url?: string | undefined;
    password?: string | undefined;
    lssOrg?: string | undefined;
    oid?: string | undefined;
    dutyCode?: string | undefined;
    lssUser?: string | undefined;
    subscriptionKey?: string | undefined;
    oAuthUrl?: string | undefined;
    oAuthGrantType?: string | undefined;
    oAuthClientId?: string | undefined;
    oAuthClientSecret?: string | undefined;
    oAuthResource?: string | undefined;
    currencyCode?: string | undefined;
    iata?: string | undefined;
    pointOfSaleCountryCode?: string | undefined;
    aggregatorId?: string | undefined;
    headerURL?: string | undefined;
    readonly hasOAuth?: boolean;
}
export interface AzulCredential extends Credential {
    readonly supplierSystemName?: string | undefined;
    url?: string | undefined;
    apiKey?: string | undefined;
}
export interface BookingFare {
    agreementCode?: string | undefined;
    exchangeRate?: number | undefined;
    originalTaxes?: Money;
    taxes?: Money;
    originalFare?: Money;
    fare?: Money;
    displayFare?: Money;
    markupedFare?: Money;
    duTaxes?: Money;
    dvTaxes?: Money;
    total?: Money;
    penalty?: Money;
    fareBasis?: string | undefined;
    travellerAgeGroup?: AgeGroup;
    fareType?: FareType;
    supplierSystem?: string | undefined;
    externalProperties?: {
        [key: string]: string;
    } | undefined;
    travellersCount?: number;
    validatingCarrier?: string | undefined;
    exchangeRateDate?: Date;
    travellerNames?: string[] | undefined;
    fareRules?: string | undefined;
    credentialIdentifier?: string | undefined;
    agreementDifference?: AgreementDifference;
}
export interface Bus {
    origin?: string | undefined;
    destination?: string | undefined;
    departure?: Date;
    arrival?: Date;
    duration?: number;
    companyName?: string | undefined;
    companyLogo?: string | undefined;
    category?: string | undefined;
    freeSeats?: number;
    fareOption?: BusFareOption;
    externalProperties?: {
        [key: string]: string;
    } | undefined;
}
export interface BusFareOption {
    amount?: Money;
    discount?: Money;
    boardingFee?: Money;
    insurance?: Money;
}
export interface BusGroup {
    supplierSystem?: string | undefined;
    category?: string | undefined;
    companyName?: string | undefined;
    companyLogo?: string | undefined;
    duration?: number;
    freeSeats?: number;
    buses?: Bus[] | undefined;
    origin?: string | undefined;
    destination?: string | undefined;
    ruleText?: string | undefined;
    price?: Money;
    firstDepartureTime?: Date;
    tags?: string[] | undefined;
}
export interface BusReservation extends Reservation {
    busTickets?: BusTicket[] | undefined;
    busSeats?: BusSeat[] | undefined;
    busGroups?: BusGroup[] | undefined;
    type?: ReservationType;
}
export interface BusSeat {
    number?: number;
    line?: number;
    column?: number;
    busy?: boolean;
    category?: string | undefined;
    fareOption?: BusFareOption;
    travelKey?: string | undefined;
}
export interface BusTicket {
    supplierTicketCode?: string | undefined;
    floor?: number;
    seat?: BusSeat;
    busGroup?: BusGroup;
    bus?: Bus;
    isOutbound?: boolean;
    traveller?: Traveller;
    couponCode?: string | undefined;
    couponTotalDiscount?: number | undefined;
    hasInsurance?: boolean;
}
export declare enum CabinType {
    FirstClass = "FirstClass",
    Business = "Business",
    Economy = "Economy",
    PremiumEconomy = "PremiumEconomy"
}
export interface ChangeHistory extends DBRecord {
    operations?: Operation[] | undefined;
    recordId?: number;
}
export interface CionsCredential extends Credential {
    readonly supplierSystemName?: string | undefined;
    airCompanyCode?: string | undefined;
    email?: string | undefined;
    password?: string | undefined;
    url?: string | undefined;
}
export interface ClickBusCredential extends Credential {
    readonly supplierSystemName?: string | undefined;
    url?: string | undefined;
    apiKey?: string | undefined;
}
export interface ContactInformation {
    email?: string | undefined;
    phone?: Phone;
    address?: Address;
}
export interface CompanyContactInformation extends ContactInformation {
    name?: string | undefined;
}
export declare enum Comparators {
    Equals = "Equals",
    NotEquals = "NotEquals",
    GreaterThan = "GreaterThan",
    GreaterThanOrEquals = "GreaterThanOrEquals",
    LessThan = "LessThan",
    LessThanOrEquals = "LessThanOrEquals",
    Contains = "Contains",
    NotContains = "NotContains",
    StartsWith = "StartsWith",
    EndsWith = "EndsWith",
    In = "In",
    NotIn = "NotIn",
    DayOfWeek = "DayOfWeek",
    Regex = "Regex"
}
export declare enum ContactPhoneType {
    Unknown = "Unknown",
    BusinessPhone = "BusinessPhone",
    HomePhoneNumber = "HomePhoneNumber",
    MobilePhone = "MobilePhone"
}
export interface CopaCredential extends FareLogixCredential {
    readonly supplierSystemName?: string | undefined;
}
export interface CredentialSupplierCredential {
    id?: number;
    active?: boolean;
    creationTime?: Date | undefined;
    lastUpdateTime?: Date | undefined;
    isDeleted?: boolean;
    accountId?: number;
    name?: string | undefined;
    credential?: Credential;
}
export interface CreditCardInformation {
    registeredCreditCardId?: number | undefined;
    creditCardNumber?: string | undefined;
    securityCode?: string | undefined;
    expireYear?: number;
    expireMonth?: number;
    providerCode?: string | undefined;
}
export interface DateTimeRange {
    min?: Date;
    max?: Date;
}
export interface Document {
    type?: DocumentTypes;
    value?: string | undefined;
    expirationDate?: Date | undefined;
    issuingCountry?: string | undefined;
}
export declare enum DocumentTypes {
    None = "None",
    Passport = "Passport",
    CPF = "CPF",
    Identity = "Identity"
}
export interface EnvisionCredential extends Credential {
    readonly supplierSystemName?: string | undefined;
    externalIdentifier?: string | undefined;
    username?: string | undefined;
}
export interface ExecuteQueryRQ {
    queryDefinition?: PredicateItem;
    projectionFields?: ProjectionField[] | undefined;
    sortingFields?: SortingField[] | undefined;
    paginationParameters?: PaginationParameters;
}
export declare enum FareType {
    Public = "Public",
    Operator = "Operator",
    Private = "Private"
}
export interface PredicateItem {
    operator?: Operators;
}
export interface Field extends PredicateItem {
    name?: string | undefined;
    comparator?: Comparators;
    value?: string | undefined;
}
export interface FieldDefinition {
    name?: string | undefined;
    dataType?: FieldDefinitionDataType;
    required?: boolean;
    allowedValues?: string[] | undefined;
    formula?: string | undefined;
}
export declare enum FieldDefinitionDataType {
    Unknow = "Unknow",
    String = "String",
    Int = "Int",
    Decimal = "Decimal",
    Boolean = "Boolean",
    DateTime = "DateTime",
    Array = "Array",
    Object = "Object"
}
export interface Flight {
    arrivalAirportId?: number;
    departureAirportId?: number;
    durationInMinutes?: number;
    layoverInMinutes?: number;
    arrivalDateTime?: Date;
    departureDateTime?: Date;
    cabinType?: CabinType;
    airCompanyCode?: string | undefined;
    status?: string | undefined;
    operatedByAirCompanyCode?: string | undefined;
    flightNumber?: string | undefined;
    externalProperties?: {
        [key: string]: string;
    } | undefined;
    legs?: FlightLeg[] | undefined;
    classOfService?: string | undefined;
    aircraftType?: string | undefined;
    airCompanyLocator?: string | undefined;
    baggagesIncluded?: number | undefined;
    arrivalAirportIATA?: string | undefined;
    departureAirportIATA?: string | undefined;
    numberOfStops?: number | undefined;
}
export interface FlightGroup {
    /** Cia Aérea Emissora */
    issuerAirCompanyCode?: string | undefined;
    /** Fornecedor do Trecho */
    supplierSystem?: string | undefined;
    /** Duração em minutos do Trecho */
    durationInMinutes?: number;
    cityPairIndex?: number;
    /** Lista de voos do trecho */
    flights?: Flight[] | undefined;
    externalProperties?: {
        [key: string]: string;
    } | undefined;
    readonly arrivalTime?: Date;
    readonly departureTime?: Date;
    readonly originIATA?: string | undefined;
    readonly destinationIATA?: string | undefined;
    readonly stops?: number;
    credentialIdentifier?: string | undefined;
}
export interface FlightLeg {
    arrivalAirportIATA?: string | undefined;
    departureAirportIATA?: string | undefined;
    arrivalDateTime?: Date;
    departureDateTime?: Date;
    durationInMinutes?: number;
}
export interface FrequentFlyer {
    airCompanyCode?: string | undefined;
    number?: string | undefined;
    travellerName?: string | undefined;
}
export declare enum Gender {
    Male = "Male",
    Female = "Female"
}
export interface GolCredential extends Credential {
    readonly supplierSystemName?: string | undefined;
    accountNumber?: string | undefined;
    accountingCity?: string | undefined;
    accountingCode?: string | undefined;
    officeStationCode?: string | undefined;
    organization?: string | undefined;
    password?: string | undefined;
    needChangeContext?: boolean;
    url?: string | undefined;
    username?: string | undefined;
    userType?: string | undefined;
}
export interface HitEntry extends DBRecord {
    organizationId?: number;
    userId?: number | undefined;
    accountId?: number;
    email?: string | undefined;
    extraInfo?: {
        [key: string]: any;
    } | undefined;
}
export interface IberiaCredential extends Credential {
    readonly supplierSystemName?: string | undefined;
    apiKey?: string | undefined;
    baseUrl?: string | undefined;
    iataNumber?: string | undefined;
}
export interface LatamCredential extends Credential {
    readonly supplierSystemName?: string | undefined;
    username?: string | undefined;
    password?: string | undefined;
    organization?: string | undefined;
    needContextChange?: boolean;
    accountingCity?: string | undefined;
    accountingCode?: string | undefined;
    iataNumber?: string | undefined;
    url?: string | undefined;
    wdUrl?: string | undefined;
    wdUsername?: string | undefined;
    wdPassword?: string | undefined;
    xApiKey?: string | undefined;
}
export interface LatamNDCCredential extends Credential {
    readonly supplierSystemName?: string | undefined;
    email?: string | undefined;
    username?: string | undefined;
    url?: string | undefined;
    countryCode?: string | undefined;
    lang?: string | undefined;
    oAuthUrl?: string | undefined;
    oAuthGrantType?: string | undefined;
    oAuthClientId?: string | undefined;
    oAuthClientSecret?: string | undefined;
    oAuthResource?: string | undefined;
    iataNumber?: string | undefined;
    aggregatorId?: string | undefined;
    aggregatorName?: string | undefined;
    agencyId?: string | undefined;
    wdUrl?: string | undefined;
    wdUsername?: string | undefined;
    wdPassword?: string | undefined;
    xApiKey?: string | undefined;
}
export interface Location extends DBRecord {
    iata?: string | undefined;
    country?: string | undefined;
    locationType?: LocationType;
    parentId?: number | undefined;
    coordinates?: Point;
    timeZone?: number | undefined;
    score?: number;
    code?: string | undefined;
    regionCode?: string | undefined;
    showInAir?: boolean;
    showInAirExpanded?: boolean;
    showInHotel?: boolean;
    showInHotelExpanded?: boolean;
    showInBus?: boolean;
    showInBusExpanded?: boolean;
    namesByCulture?: {
        [key: string]: string;
    } | undefined;
    supplierSystemInformations?: {
        [key: string]: {
            [key: string]: any;
        };
    } | undefined;
}
export declare enum LocationType {
    World = "World",
    Continent = "Continent",
    Country = "Country",
    State = "State",
    City = "City",
    Airport = "Airport",
    Region = "Region",
    Spot = "Spot",
    Port = "Port",
    BusStation = "BusStation",
    Hotel = "Hotel"
}
export interface Money {
    value?: number;
    currencyCode?: string | undefined;
}
export interface OSI {
    code?: string | undefined;
    text?: string | undefined;
    airCompanyCode?: string | undefined;
    travellerName?: string | undefined;
    externalProperties?: {
        [key: string]: string;
    } | undefined;
}
export interface Operation {
    path?: string | undefined;
    op?: string | undefined;
    value?: string | undefined;
}
export declare enum Operators {
    And = "And",
    Or = "Or"
}
export interface Organization extends DBRecord {
    name?: string | undefined;
    identifier?: string | undefined;
    public?: boolean;
    accountPlaceHolderId?: number | undefined;
    setupStepsCompleted?: boolean;
    defaultCulture?: string | undefined;
}
export interface PaginationParameters {
    skip?: number;
    limit?: number;
}
export interface Parenthesis extends PredicateItem {
    items?: PredicateItem[] | undefined;
}
export interface Payment {
    identification?: string | undefined;
    description?: string | undefined;
    totalValue?: Money;
    points?: number | undefined;
    firstInstallmentValue?: Money;
    otherInstallmentValue?: Money;
    authorizationTime?: Date | undefined;
    authorizationCode?: string | undefined;
    installments?: number | undefined;
    interest?: number | undefined;
    externalProperties?: {
        [key: string]: string;
    } | undefined;
    transactionId?: string | undefined;
    reversalTransactionId?: string | undefined;
    transactionTime?: Date | undefined;
    status?: PaymentStatus;
    method?: PaymentMethod;
    owner?: PaymentOwner;
    creditCardInformation?: CreditCardInformation;
    airTicketReplacementInformation?: AirTicketReplacementInformation;
    paymentBrokerName?: string | undefined;
}
export declare enum PaymentMethod {
    CreditCard = "CreditCard",
    Invoice = "Invoice",
    Points = "Points",
    AirTicketReplacement = "AirTicketReplacement",
    CreditCardRegistered = "CreditCardRegistered",
    Cash = "Cash",
    Billet = "Billet",
    Check = "Check",
    DirectPayment = "DirectPayment",
    BankTransfer = "BankTransfer",
    PointOfSale = "PointOfSale",
    Financial = "Financial",
    DiscountCoupon = "DiscountCoupon"
}
export interface PaymentOwner {
    name?: string | undefined;
    document?: string | undefined;
    birthDate?: Date | undefined;
    email?: string | undefined;
    address?: Address;
    buyerId?: number | undefined;
    documentType?: string | undefined;
    gender?: Gender;
    phone?: string | undefined;
}
export declare enum PaymentStatus {
    None = "None",
    Pending = "Pending",
    Confirmed = "Confirmed",
    NotConfirmed = "NotConfirmed",
    Canceled = "Canceled",
    PreAuthorized = "PreAuthorized"
}
export interface PersonRecord extends Record {
    readonly recordTypeName?: string | undefined;
    userId?: number;
    firstName?: string | undefined;
    lastName?: string | undefined;
    email?: string | undefined;
    birthDate?: Date;
    documents?: Document[] | undefined;
    membershipProgram?: FrequentFlyer;
    [key: string]: any;
}
export interface Phone {
    countryCallingCode?: string | undefined;
    countryCode?: string | undefined;
    areaCode?: string | undefined;
    phoneNumber?: string | undefined;
    contactType?: ContactPhoneType;
}
export interface Point {
    type?: string | undefined;
    coordinates?: number[] | undefined;
    x?: number;
    y?: number;
}
export interface ProjectionField {
    fieldName?: string | undefined;
    exclude?: boolean;
}
export interface QueryByIndexRQ {
    recordTypeName?: string | undefined;
    query?: string | undefined;
    fields?: string[] | undefined;
}
export interface QueryByIndexRS {
    recordTypeName?: string | undefined;
    results?: QueryByIndexResult[] | undefined;
}
export interface QueryByIndexResult {
    fields?: {
        [key: string]: any;
    } | undefined;
}
export interface QueryTracePaginationParameters extends PaginationParameters {
    limit?: number;
}
export interface RecordQuery extends DBRecord {
    name?: string | undefined;
    queryDefinition?: PredicateItem;
    projectionFields?: ProjectionField[] | undefined;
    sortingFields?: SortingField[] | undefined;
}
export interface RecordQueryCreateRQ {
    name?: string | undefined;
    queryDefinition?: PredicateItem;
    projectionFields?: ProjectionField[] | undefined;
    sortingFields?: SortingField[] | undefined;
}
export interface RecordQueryExecuteRQ {
    id?: number;
    paginationParameters?: PaginationParameters;
}
export interface RecordQueryExecuteRS {
    records?: Record[] | undefined;
    pageNumber?: number;
    totalPages?: number;
    totalRecords?: number;
    paginationParameters?: PaginationParameters;
}
export interface RecordQueryUpdateRQ {
    name?: string | undefined;
    queryDefinition?: PredicateItem;
    projectionFields?: ProjectionField[] | undefined;
    sortingFields?: SortingField[] | undefined;
}
export interface RecordType extends DBRecord {
    name?: string | undefined;
    fields?: FieldDefinition[] | undefined;
    recordTypedName?: string | undefined;
    recordTypedContract?: string | undefined;
}
export interface RecordTypeCreateRQ {
    name?: string | undefined;
    fields?: FieldDefinition[] | undefined;
    recordTypedName?: string | undefined;
    recordTypedContract?: string | undefined;
}
export interface RecordTypeUpdateRQ {
    name?: string | undefined;
    fields?: FieldDefinition[] | undefined;
    recordTypedName?: string | undefined;
    recordTypedContract?: string | undefined;
}
export interface Relationship {
    recordId?: number;
    relationshipType?: RelationshipTypes;
}
export declare enum RelationshipTypes {
    Associated = "Associated"
}
export interface Remark {
    text?: string | undefined;
    restrict?: boolean;
    externalProperties?: {
        [key: string]: string;
    } | undefined;
}
export declare enum ReservationStatus {
    Booked = "Booked",
    Canceled = "Canceled",
    BookPending = "BookPending",
    Queued = "Queued",
    CancellationPending = "CancellationPending",
    Rejected = "Rejected",
    TechnicalProblem = "TechnicalProblem"
}
export declare enum ReservationType {
    Air = "Air",
    Hotel = "Hotel",
    Services = "Services",
    Car = "Car",
    Insurance = "Insurance",
    Cruise = "Cruise",
    CruiseGroup = "CruiseGroup",
    Bus = "Bus"
}
export interface SSR {
    code?: string | undefined;
    airCompanyCode?: string | undefined;
    text?: string | undefined;
    travellerName?: string | undefined;
    externalProperties?: {
        [key: string]: string;
    } | undefined;
}
export interface SabreCredential extends Credential {
    readonly supplierSystemName?: string | undefined;
    connectionName?: string | undefined;
    username?: string | undefined;
    password?: string | undefined;
    url?: string | undefined;
    pcc?: string | undefined;
    ipcc?: string | undefined;
    suffix?: string | undefined;
    jumpPCC?: string | undefined;
    iata?: string | undefined;
    infoSource?: string | undefined;
    pccForAuth?: string | undefined;
    itins?: string | undefined;
}
export declare enum SeatStatus {
    Pending = "Pending",
    Charged = "Charged",
    NotChargeable = "NotChargeable",
    Cancelled = "Cancelled"
}
export interface SortingField {
    fieldName?: string | undefined;
    ascendingSort?: boolean;
}
export interface Supplier extends DBRecord {
    name?: string | undefined;
    identifier?: string | undefined;
    url?: string | undefined;
    logoUrl?: string | undefined;
}
export interface SupplierCredential extends CredentialSupplierCredential {
}
export interface SupplierCredential_1 extends BaseProfileRecord {
    name?: string | undefined;
    credential?: T;
}
export interface T {
    readonly supplierSystemName?: string | undefined;
    travelAgencyContactInformation?: CompanyContactInformation;
    maxSessionPoolConnections?: number;
    isProductionEnvironment?: boolean;
    credentialPublicFare?: Credential;
}
export interface TSA {
    birthDate?: Date | undefined;
    gender?: Gender;
    redressNumber?: string | undefined;
    travellerName?: string | undefined;
}
export interface TicketsPaymentsRelationship {
    paymentIdentifications?: string[] | undefined;
    ticketNumbers?: string[] | undefined;
}
export interface Trace extends DBRecord {
    provider?: string | undefined;
    location?: string | undefined;
    fileName?: string | undefined;
    filePath?: string | undefined;
    traceInfos?: {
        [key: string]: any;
    } | undefined;
}
export interface TravellerBasicInfo {
    ageGroup?: AgeGroup;
}
export interface Traveller extends TravellerBasicInfo {
    firstName?: string | undefined;
    middleName?: string | undefined;
    lastName?: string | undefined;
    nationality?: string | undefined;
    gender?: Gender;
    birthDate?: Date | undefined;
    externalProperties?: {
        [key: string]: string;
    } | undefined;
    loyaltyCode?: string | undefined;
    documents?: Document[] | undefined;
    redressNnumber?: string | undefined;
    contactInformation?: ContactInformation;
    readonly fullName?: string | undefined;
}
export interface TripAPIOrder extends DBRecord {
    accountId?: number;
    callId?: string | undefined;
    tripAPIReservations?: TripAPIReservation[] | undefined;
}
export interface TripAPIReservation extends DBRecord {
    tripAPIOrderId?: number | undefined;
    createdByTripAPI?: boolean;
    reservation?: Reservation;
}
export interface TripRecord extends Record {
    readonly recordTypeName?: string | undefined;
    readonly origin?: string | undefined;
    readonly destination?: string | undefined;
    readonly startDate?: Date | undefined;
    [key: string]: any;
}
export declare enum TripType {
    OneWay = "OneWay",
    RoundTrip = "RoundTrip",
    MultiDestination = "MultiDestination"
}
export interface User extends BaseProfileRecord {
    avatar?: string | undefined;
    email?: string | undefined;
    externalIdentifier?: string | undefined;
    name?: string | undefined;
    invitedAccepted?: boolean;
    invitedTime?: Date;
    culture?: string | undefined;
}
export interface UserGroup extends BaseProfileRecord {
    name?: string | undefined;
}
export declare class ApiException extends Error {
    message: string;
    status: number;
    response: string;
    headers: {
        [key: string]: any;
    };
    result: any;
    constructor(message: string, status: number, response: string, headers: {
        [key: string]: any;
    }, result: any);
    protected isApiException: boolean;
    static isApiException(obj: any): obj is ApiException;
}
