import React, { CSSProperties } from 'react';
import { TFunction } from 'i18next';
import { Theme } from '@mui/material';
import { InternalAxiosRequestConfig, AxiosInstance, AxiosResponse } from 'axios';

interface AvatarEnvisionProps {
    user: {
        firstName: string;
        lastName: string;
        avatar: string | null;
    };
    backgroundColor: string;
    color: string;
    style?: React.CSSProperties;
}
declare function Avatar(props: AvatarEnvisionProps): React.JSX.Element;

type LoadingCircularProgressProps = {
    open: boolean;
    styles?: CSSProperties;
};
declare function LoadingCircularProgress(props: LoadingCircularProgressProps): React.JSX.Element;

declare enum CommonSize {
    small = 0,
    medium = 1,
    large = 2
}

declare enum Gender {
    Male = "Male",
    Female = "Female"
}

declare enum AgeGroup {
    Adult = "Adult",
    Child = "Child",
    Infant = "Infant"
}

declare enum ContactPhoneType {
    Unknown = "Unknown",
    BusinessPhone = "BusinessPhone",
    HomePhoneNumber = "HomePhoneNumber",
    MobilePhone = "MobilePhone"
}

interface Address {
    street?: string | undefined;
    number?: string | undefined;
    complement?: string | undefined;
    zipCode?: string | undefined;
    neighborhood?: string | undefined;
    city?: string | undefined;
    state?: string | undefined;
    countryCode?: string | undefined;
    longitude?: number | undefined;
    latitude?: number | undefined;
}

interface Phone {
    countryCallingCode?: string | undefined;
    countryCode?: string | undefined;
    areaCode?: string | undefined;
    phoneNumber?: string | undefined;
    contactType?: ContactPhoneType;
}

interface ContactInformation {
    email?: string | undefined;
    phone?: Phone;
    address?: Address;
}

interface FrequentFlyer {
    airCompanyCode?: string | undefined;
    number?: string | undefined;
    travellerName?: string | undefined;
}

interface TravellerBasicInfo {
    ageGroup?: AgeGroup;
}

interface Traveller extends TravellerBasicInfo {
    firstName?: string | undefined;
    middleName?: string | undefined;
    lastName?: string | undefined;
    nationality?: string | undefined;
    gender?: Gender;
    birthDate?: Date | undefined;
    externalProperties?: {
        [key: string]: string;
    } | undefined;
    frequentFlyers?: FrequentFlyer[] | undefined;
    documents?: Document[] | undefined;
    redressNnumber?: string | undefined;
    contactInformation?: ContactInformation;
    readonly fullName?: string | undefined;
}

interface DBRecord$1 {
    id?: number;
    active?: boolean;
    creationTime?: Date | undefined;
    lastUpdateTime?: Date | undefined;
    isDeleted?: boolean;
}

interface AirCompany extends DBRecord$1 {
    code?: string | undefined;
    name?: string | undefined;
    displayName?: string | undefined;
    showOnEngine?: boolean;
}

type TravelersDetailProps = {
    travelers: Traveller[];
    t: TFunction;
};
declare function TravelersDetail(props: TravelersDetailProps): React.JSX.Element;

type TravelerTestFormProps = {
    baseUrl: string;
};
declare function TravelerTestForm(props: TravelerTestFormProps): React.JSX.Element;

type DialogDetailProps = {
    open: boolean;
    selectedTraveller: Traveller;
    handleOpenEditDetails: () => void;
    handleOpenEditAdditionalInfo: () => void;
    handleOpenDialog: (open: boolean, traveller: Traveller | null) => void;
    t: TFunction;
    theme: Theme;
};
declare function DialogTravelerDetail(props: DialogDetailProps): React.JSX.Element;

declare function addTravelersDetailTranslationResources(i18nInstance: any): void;

interface Person {
    id: number;
    userId: number;
    firstName: string;
    lastName: string;
    email: string;
    birthDate: Date;
    avatar: string | null;
    phone: string;
    gender: Gender;
    traveler: Traveller;
}

declare function convertLoggedUserToPerson(id: number, displayName: string, photoURL?: string, email?: string): Person;

declare function convertDateFieldToDateOnly(config: InternalAxiosRequestConfig<any>, field: string): void;

declare function stringToHslColor(str: string, saturation: number, lightness: number): string;

declare function convertDateToDateOnly(date: Date): string;

declare const DEBOUNCE_TIME_DEFAULT = 200;

declare function getDocumentMask(documentType: string): string;
declare function validateCPF(cpf: string): boolean;
declare function sanitizeDocument(document: string): string;

declare class RecordsAPIClient {
    protected instance: AxiosInstance;
    protected baseUrl: string;
    protected jsonParseReviver: ((key: string, value: any) => any) | undefined;
    constructor(baseUrl: string, instance?: AxiosInstance);
    /**
     * @param body (optional)
     * @return Success
     */
    recordPost(body: Record | undefined, signal?: AbortSignal): Promise<Record>;
    protected processRecordPost(response: AxiosResponse): Promise<Record>;
    /**
     * @param body (optional)
     * @return Success
     */
    recordQueryByIndex(body: QueryByIndexRQ | undefined, signal?: AbortSignal): Promise<QueryByIndexRS>;
    protected processRecordQueryByIndex(response: AxiosResponse): Promise<QueryByIndexRS>;
    /**
     * @param body (optional)
     * @return Success
     */
    recordPatch(id: number, body: Record | undefined, signal?: AbortSignal): Promise<Record>;
    protected processRecordPatch(response: AxiosResponse): Promise<Record>;
    /**
     * @return Success
     */
    recordGet(id: number, signal?: AbortSignal): Promise<Record>;
    protected processRecordGet(response: AxiosResponse): Promise<Record>;
    /**
     * @return Success
     */
    recordDelete(id: number, signal?: AbortSignal): Promise<void>;
    protected processRecordDelete(response: AxiosResponse): Promise<void>;
    /**
     * @return Success
     */
    recordGetSingleByIdentifier(identifier: string, signal?: AbortSignal): Promise<Record>;
    protected processRecordGetSingleByIdentifier(response: AxiosResponse): Promise<Record>;
    /**
     * @param id (optional)
     * @param recordId (optional)
     * @param type (optional)
     * @return Success
     */
    recordAddRelationship(id: number | undefined, recordId: number | undefined, type: RelationshipTypes | undefined, signal?: AbortSignal): Promise<void>;
    protected processRecordAddRelationship(response: AxiosResponse): Promise<void>;
    /**
     * @param id (optional)
     * @param recordId (optional)
     * @return Success
     */
    recordRemoveRelationship(id: number | undefined, recordId: number | undefined, signal?: AbortSignal): Promise<void>;
    protected processRecordRemoveRelationship(response: AxiosResponse): Promise<void>;
    /**
     * @param body (optional)
     * @return Success
     */
    recordQueryPost(body: RecordQueryCreateRQ | undefined, signal?: AbortSignal): Promise<RecordQuery>;
    protected processRecordQueryPost(response: AxiosResponse): Promise<RecordQuery>;
    /**
     * @param body (optional)
     * @return Success
     */
    recordQueryExecute(body: ExecuteQueryRQ | undefined, signal?: AbortSignal): Promise<RecordQueryExecuteRS>;
    protected processRecordQueryExecute(response: AxiosResponse): Promise<RecordQueryExecuteRS>;
    /**
     * @param body (optional)
     * @return Success
     */
    recordQueryPatch(id: number, body: RecordQueryUpdateRQ | undefined, signal?: AbortSignal): Promise<RecordQuery>;
    protected processRecordQueryPatch(response: AxiosResponse): Promise<RecordQuery>;
    /**
     * @return Success
     */
    recordQueryGet(id: number, signal?: AbortSignal): Promise<RecordQuery>;
    protected processRecordQueryGet(response: AxiosResponse): Promise<RecordQuery>;
    /**
     * @return Success
     */
    recordQueryDelete(id: number, signal?: AbortSignal): Promise<void>;
    protected processRecordQueryDelete(response: AxiosResponse): Promise<void>;
    /**
     * @param body (optional)
     * @return Success
     */
    recordQueryExecuteById(body: RecordQueryExecuteRQ | undefined, signal?: AbortSignal): Promise<RecordQueryExecuteRS>;
    protected processRecordQueryExecuteById(response: AxiosResponse): Promise<RecordQueryExecuteRS>;
    /**
     * @param body (optional)
     * @return Success
     */
    recordTypePost(body: RecordTypeCreateRQ | undefined, signal?: AbortSignal): Promise<RecordType>;
    protected processRecordTypePost(response: AxiosResponse): Promise<RecordType>;
    /**
     * @param body (optional)
     * @return Success
     */
    recordTypePatch(id: number, body: RecordTypeUpdateRQ | undefined, signal?: AbortSignal): Promise<RecordType>;
    protected processRecordTypePatch(response: AxiosResponse): Promise<RecordType>;
    /**
     * @return Success
     */
    recordTypeGet(id: number, signal?: AbortSignal): Promise<RecordType>;
    protected processRecordTypeGet(response: AxiosResponse): Promise<RecordType>;
    /**
     * @return Success
     */
    recordTypeDelete(id: number, signal?: AbortSignal): Promise<void>;
    protected processRecordTypeDelete(response: AxiosResponse): Promise<void>;
}
interface DBRecord {
    id?: number;
    active?: boolean;
    creationTime?: Date | undefined;
    lastUpdateTime?: Date | undefined;
    isDeleted?: boolean;
}
interface Record extends DBRecord {
    readonly recordTypeName?: string | undefined;
    accountId?: number;
    parentId?: number;
    identifier?: string | undefined;
    relationships?: Relationship[] | undefined;
    [key: string]: any;
}
interface ExecuteQueryRQ {
    queryDefinition?: PredicateItem;
    projectionFields?: ProjectionField[] | undefined;
    sortingFields?: SortingField[] | undefined;
    paginationParameters?: PaginationParameters;
}
interface PredicateItem {
    operator?: Operators;
}
interface FieldDefinition {
    name?: string | undefined;
    dataType?: FieldDefinitionDataType;
    required?: boolean;
    allowedValues?: string[] | undefined;
    formula?: string | undefined;
}
declare enum FieldDefinitionDataType {
    Unknow = "Unknow",
    String = "String",
    Int = "Int",
    Decimal = "Decimal",
    Boolean = "Boolean",
    DateTime = "DateTime",
    Array = "Array",
    Object = "Object"
}
declare enum Operators {
    And = "And",
    Or = "Or"
}
interface PaginationParameters {
    skip?: number;
    limit?: number;
}
interface ProjectionField {
    fieldName?: string | undefined;
    exclude?: boolean;
}
interface QueryByIndexRQ {
    recordTypeName?: string | undefined;
    query?: string | undefined;
    fields?: string[] | undefined;
}
interface QueryByIndexRS {
    recordTypeName?: string | undefined;
    results?: QueryByIndexResult[] | undefined;
}
interface QueryByIndexResult {
    fields?: {
        [key: string]: any;
    } | undefined;
}
interface RecordQuery extends DBRecord {
    name?: string | undefined;
    queryDefinition?: PredicateItem;
    projectionFields?: ProjectionField[] | undefined;
    sortingFields?: SortingField[] | undefined;
}
interface RecordQueryCreateRQ {
    name?: string | undefined;
    queryDefinition?: PredicateItem;
    projectionFields?: ProjectionField[] | undefined;
    sortingFields?: SortingField[] | undefined;
}
interface RecordQueryExecuteRQ {
    id?: number;
    paginationParameters?: PaginationParameters;
}
interface RecordQueryExecuteRS {
    records?: Record[] | undefined;
    pageNumber?: number;
    totalPages?: number;
    totalRecords?: number;
    paginationParameters?: PaginationParameters;
}
interface RecordQueryUpdateRQ {
    name?: string | undefined;
    queryDefinition?: PredicateItem;
    projectionFields?: ProjectionField[] | undefined;
    sortingFields?: SortingField[] | undefined;
}
interface RecordType extends DBRecord {
    name?: string | undefined;
    fields?: FieldDefinition[] | undefined;
    recordTypedName?: string | undefined;
    recordTypedContract?: string | undefined;
}
interface RecordTypeCreateRQ {
    name?: string | undefined;
    fields?: FieldDefinition[] | undefined;
    recordTypedName?: string | undefined;
    recordTypedContract?: string | undefined;
}
interface RecordTypeUpdateRQ {
    name?: string | undefined;
    fields?: FieldDefinition[] | undefined;
    recordTypedName?: string | undefined;
    recordTypedContract?: string | undefined;
}
interface Relationship {
    recordId?: number;
    relationshipType?: RelationshipTypes;
}
declare enum RelationshipTypes {
    Associated = "Associated"
}
interface SortingField {
    fieldName?: string | undefined;
    ascendingSort?: boolean;
}

export { Address, AgeGroup, AirCompany, Avatar, CommonSize, ContactInformation, ContactPhoneType, DBRecord$1 as DBRecord, DEBOUNCE_TIME_DEFAULT, DialogTravelerDetail, FrequentFlyer, Gender, LoadingCircularProgress as Loader, Person, Phone, RecordsAPIClient, TravelerTestForm, TravelersDetail, Traveller, TravellerBasicInfo, addTravelersDetailTranslationResources, convertDateFieldToDateOnly, convertDateToDateOnly, convertLoggedUserToPerson, getDocumentMask, sanitizeDocument, stringToHslColor, validateCPF };
